#include "project.h"

#define LED_ON  (0u)
#define LED_OFF (1u)

#define TIMER_PERIOD 1000
#define RED_PERIOD   1000
#define GREEN_PERIOD  500
#define BLUE_PERIOD   250

volatile int     pit_flag = 0 ;

CY_ISR(timer_isr)
{
    Timer_1ms_ClearInterrupt(Timer_1ms_INTR_MASK_TC) ;
    pit_flag = 1 ;
}

void do_red(int count)
{
    if ((count % RED_PERIOD) < (RED_PERIOD/2)) {
        LED_R_Write(LED_OFF) ;
    } else {
        LED_R_Write(LED_ON) ;
    }
}

void do_green(int count) 
{
    if ((count % GREEN_PERIOD) < (GREEN_PERIOD/2)) {
        LED_G_Write(LED_OFF) ;
    } else {
        LED_G_Write(LED_ON) ;
    }
}

void do_blue(int count)
{
    if ((count % BLUE_PERIOD) < (BLUE_PERIOD/2)) {
        LED_B_Write(LED_OFF) ;
    } else {
        LED_B_Write(LED_ON) ;
    }
}

int main(void)
{
    int count = 0 ;
    int task = 0 ;
    
    isr_1ms_StartEx(timer_isr) ; /* set isr to the interrupt */
    Timer_1ms_Start() ;
    
    CyGlobalIntEnable; /* Enable global interrupts. */

    for(;;) {
        if (pit_flag) {
            switch(task) {
            case 0: 
                do_red(count) ;
                task = 1 ;
                break ;
            case 1:
                do_green(count) ;
                task = 2 ;
                break ;
            case 2:
                do_blue(count) ;
                task = 0 ;
                break ;
            default:
                task = 0 ;
                break ;
            }
            count = (count + 1) % TIMER_PERIOD ;             
            pit_flag = 0 ;
        }

    }
}
